@@ -7,7 +7,7 @@
 #ifndef KANDROIDEXTRAS_JNISIGNATURE_H
 #define KANDROIDEXTRAS_JNISIGNATURE_H
 
-#include "jnicommon.h"
+#include "jnitypes.h"
 
 #include <jni.h>
 #include <cstdint>
@@ -15,6 +15,10 @@
 
 namespace KAndroidExtras {
 
+namespace Jni {
+template <typename T> class Array;
+}
+
 /** @cond internal */
 namespace Internal {
 
@@ -53,7 +57,7 @@ template <typename, typename> struct staticStringFromJniType;
 template <typename T, std::size_t... Indexes>
 struct staticStringFromJniType<T, std::index_sequence<Indexes...>>
 {
-    typedef StaticString<T::jniName()[Indexes]...> value;
+    typedef StaticString<Jni::typeName<T>()[Indexes]...> value;
 };
 
 /** Meta function for assembling JNI signatures. */
@@ -63,19 +67,21 @@ struct JniSignature
     constexpr inline auto operator()() const
     {
         using namespace Internal;
-        return static_concat(StaticString<'L'>(), typename staticStringFromJniType<T, std::make_index_sequence<static_strlen(T::jniName())>>::value(), StaticString<';'>());
+        return static_concat(StaticString<'L'>(), typename staticStringFromJniType<T, std::make_index_sequence<static_strlen(Jni::typeName<T>())>>::value(), StaticString<';'>());
     }
 };
 
-template <> struct JniSignature<bool> { constexpr inline auto operator()() const { return StaticString<'Z'>(); } };
-template <> struct JniSignature<uint8_t> { constexpr inline auto operator()() const { return StaticString<'B'>(); } };
-template <> struct JniSignature<char> { constexpr inline auto operator()() const { return StaticString<'C'>(); } };
-template <> struct JniSignature<short> { constexpr inline auto operator()() const { return StaticString<'S'>(); } };
-template <> struct JniSignature<int> { constexpr inline auto operator()() const { return StaticString<'I'>(); } };
+template <> struct JniSignature<jboolean> { constexpr inline auto operator()() const { return StaticString<'Z'>(); } };
+template <> struct JniSignature<jbyte> { constexpr inline auto operator()() const { return StaticString<'B'>(); } };
+template <> struct JniSignature<jchar> { constexpr inline auto operator()() const { return StaticString<'C'>(); } };
+template <> struct JniSignature<jshort> { constexpr inline auto operator()() const { return StaticString<'S'>(); } };
+template <> struct JniSignature<jint> { constexpr inline auto operator()() const { return StaticString<'I'>(); } };
 template <> struct JniSignature<jlong> { constexpr inline auto operator()() const { return StaticString<'J'>(); } };
-template <> struct JniSignature<float> { constexpr inline auto operator()() const { return StaticString<'F'>(); } };
-template <> struct JniSignature<double> { constexpr inline auto operator()() const { return StaticString<'D'>(); } };
+template <> struct JniSignature<jfloat> { constexpr inline auto operator()() const { return StaticString<'F'>(); } };
+template <> struct JniSignature<jdouble> { constexpr inline auto operator()() const { return StaticString<'D'>(); } };
 template <> struct JniSignature<void> { constexpr inline auto operator()() const { return StaticString<'V'>(); } };
+// special case due to jboolean != bool
+template <> struct JniSignature<bool> { constexpr inline auto operator()() const { return StaticString<'Z'>(); } };
 
 template <typename T>
 struct JniSignature<T*>
